//+------------------------------------------------------------------+
//|                                                 Dolly Simple.mq4 |
//|                      Copyright  2006, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+
#property copyright "Copyright  2006, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

#property indicator_chart_window

/*********************************************************************
* Author: Muhammad Hamizi Jaminan (hymns)
* 
* Original Author: valasholic@yahoo.com
* Mode & stuff by: Linuxser (forex-std)
*
* Date: December 14, 2006
* Custom Indicator: Dolly_Simple.mq4
* Version: 1.0.1
* Description: Breakout Strategy
*
* Change Logs
* Version 1.0.1
* - Rewrote code base on Dolly v0.3 request by babarmughal
* - Speed-up code and reduce lag on load
**********************************************************************/

//+------------------------------------------------------------------+
//| User input values                                                |
//+------------------------------------------------------------------+
extern int Back_TEST_Days = 0;
extern bool Open_Daily_Center = true;

extern int BUY_Target_2 = 55;
extern int BUY_Target_1 =40;
extern int BUY_Area =20;
extern int SELL_Area = 20;
extern int SELL_Target_1 =40;
extern int SELL_Target_2 =55;

extern color BUY_Color_2 = C'0,0,150';
extern color BUY_Color_1 = C'0,0,100';
extern color SELL_Color_1 = C'120,0,0';
extern color SELL_Color_2 = C'180,0,0';

extern bool Show_Pivot_Lines = false;
extern int PivotPoint_ExtendLINE = 0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
//----
   return(0);
  }

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   //Area Line
   ObjectDelete("BuyArea3");
   ObjectDelete("BuyArea2");
   ObjectDelete("BuyArea1");
   ObjectDelete("DailyOpen");
   ObjectDelete("SellArea1");
   ObjectDelete("SellArea2");
   ObjectDelete("SellArea3");
   
   //Area Label
   ObjectDelete("LabelBuyArea3");
   ObjectDelete("LabelBuyArea2");
   ObjectDelete("LabelBuyArea1");
   ObjectDelete("LabelCentreArea");
   ObjectDelete("LabelSellArea1");
   ObjectDelete("LabelSellArea2");
   
   //Pivot Line
   ObjectDelete("RR3");
   ObjectDelete("RR2");
   ObjectDelete("RR1");
   ObjectDelete("P1");
   ObjectDelete("SS1");
   ObjectDelete("SS2");
   ObjectDelete("SS3");
   
   //Pivot Label
   ObjectDelete("LabelR3");
   ObjectDelete("LabelR2");
   ObjectDelete("LabelR1");
   ObjectDelete("LabelPV");
   ObjectDelete("LabelS1");
   ObjectDelete("LabelS2");
   ObjectDelete("LabelS3");  
//----
   return(0);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int counted_bars=IndicatorCounted();
   CleanObject();
   BuildDolly();
//----
   
//----
   return(0);
  }
  
  
//+------------------------------------------------------------------+
//| Dolly Simple Version function                                    |
//+------------------------------------------------------------------+
/*
* Clean Object
*/
void CleanObject() {
   //Area Line
   ObjectDelete("BuyArea3");
   ObjectDelete("BuyArea2");
   ObjectDelete("BuyArea1");
   ObjectDelete("DailyOpen");
   ObjectDelete("SellArea1");
   ObjectDelete("SellArea2");
   ObjectDelete("SellArea3");
   
   //Area Label
   ObjectDelete("LabelBuyArea3");
   ObjectDelete("LabelBuyArea2");
   ObjectDelete("LabelBuyArea1");
   ObjectDelete("LabelCentreArea");
   ObjectDelete("LabelSellArea1");
   ObjectDelete("LabelSellArea2");
   
   //Pivot Line
   ObjectDelete("RR3");
   ObjectDelete("RR2");
   ObjectDelete("RR1");
   ObjectDelete("P1");
   ObjectDelete("SS1");
   ObjectDelete("SS2");
   ObjectDelete("SS3");
   
   //Pivot Label
   ObjectDelete("LabelR3");
   ObjectDelete("LabelR2");
   ObjectDelete("LabelR1");
   ObjectDelete("LabelPV");
   ObjectDelete("LabelS1");
   ObjectDelete("LabelS2");
   ObjectDelete("LabelS3");  
}

/*
* Create Area Line
*/
void CreateAreaGraphics(string ObjectArea, double start, double end, color clr)
{
   ObjectCreate(ObjectArea, OBJ_RECTANGLE, 0, iTime(NULL,1440,Back_TEST_Days), start, Time[0], end);
   ObjectSet(ObjectArea, OBJPROP_COLOR, clr);
   ObjectSet(ObjectArea,OBJPROP_BACK,false);
   ObjectSet(ObjectArea,OBJPROP_WIDTH,0);
   ObjectSet(ObjectArea,OBJPROP_STYLE,0);
}

/*
* Create Area Label
*/
void CreateAreaLabel(string ObjectNames, string ObjectLabel, double ObjectValue, color ObjectColor) 
{
   if(ObjectFind(ObjectNames) != 0) 
   {
         ObjectCreate(ObjectNames, OBJ_TEXT, 0, iTime(NULL,1440,Back_TEST_Days), ObjectValue);
         ObjectSetText(ObjectNames, ObjectLabel, 8, "Arial", ObjectColor);
         ObjectSet(ObjectNames,OBJPROP_BACK,true);
   }
   else{
         ObjectMove(ObjectNames, 0, iTime(NULL,1440,Back_TEST_Days), ObjectValue);
   }
}

/*
* Create Pivots Label
*/
void CreatePivotAreaLabel(string ObjectNames, string ObjectLabel, double ObjectValue, color ObjectColor) 
{
   if(ObjectFind(ObjectNames) != 0) 
   {
         ObjectCreate(ObjectNames, OBJ_TEXT, 0, Time[0], ObjectValue);
         ObjectSetText(ObjectNames, ObjectLabel, 8, "Arial", ObjectColor);
         ObjectSet(ObjectNames,OBJPROP_BACK,true);
   }
   else{
         ObjectMove(ObjectNames, 0, Time[0], ObjectValue);
   }
}

/*
* Create Center Lines
*/
void CreateCenterLine(string Pivots, double start, double end, double w, double s,color clr)
{
   ObjectCreate(Pivots, OBJ_TRENDBYANGLE, 0, iTime(NULL,1440,PivotPoint_ExtendLINE+Back_TEST_Days), start, Time[0],w,s, end);
   ObjectSet(Pivots, OBJPROP_COLOR, clr);
   ObjectSet(Pivots,OBJPROP_RAY,false);
   ObjectSet(Pivots,OBJPROP_WIDTH,w);
   ObjectSet(Pivots,OBJPROP_STYLE,s);
}

/*
* Create Pivots Lines
*/
void CreatePivotsLines(string PivotsLines, double start, double end, double w, double s, color clr)
{
   ObjectCreate(PivotsLines, OBJ_TRENDBYANGLE, 0, iTime(NULL,1440,0), start, Time[0],w,s, end);
   ObjectSet(PivotsLines, OBJPROP_COLOR, clr);
   ObjectSet(PivotsLines,OBJPROP_RAY,false);
   ObjectSet(PivotsLines,OBJPROP_BACK,true);
   ObjectSet(PivotsLines,OBJPROP_WIDTH,w);
   ObjectSet(PivotsLines,OBJPROP_STYLE,s);
}

/*
* Create Dolly Object
*/
void BuildDolly() {

    //Pivots & M Pivots
    double P = (iHigh(NULL,PERIOD_D1,Back_TEST_Days+1) + iLow(NULL,PERIOD_D1,Back_TEST_Days+1) + iClose(NULL,PERIOD_D1,Back_TEST_Days+1)) / 3;
    double r3 = ( 2 * P ) + ( iHigh(NULL,PERIOD_D1,Back_TEST_Days+1) - ( 2 * iLow(NULL,PERIOD_D1,Back_TEST_Days+1) ));
    double r2 = P + ( iHigh(NULL,PERIOD_D1,Back_TEST_Days+1) - iLow(NULL,PERIOD_D1,Back_TEST_Days+1) );
    double r1 = ( 2 * P ) - iLow(NULL,PERIOD_D1,Back_TEST_Days+1);
    double s1 = ( 2 * P ) - iHigh(NULL,PERIOD_D1,Back_TEST_Days+1);
    double s2 = P - ( iHigh(NULL,PERIOD_D1,Back_TEST_Days+1)- iLow(NULL,PERIOD_D1,Back_TEST_Days+1));
    double s3 = ( 2 * P ) - ( ( 2 * iHigh(NULL,PERIOD_D1,Back_TEST_Days+1) ) - iLow(NULL,PERIOD_D1,Back_TEST_Days+1) );

    double OPEN = iOpen(NULL,PERIOD_D1,0);
    double CLOSE = iClose(NULL,PERIOD_D1,0);
    
    double CenterValue;
    
    int i, limit;
    
    //Center Value Switch    
    if (Open_Daily_Center == true) { CenterValue = OPEN; }
    else { CenterValue = P; }
        
    //Buy & Sell Area
    double B1 = CenterValue + BUY_Area * Point; // Logic to determine Buy Area 
    double S1 = CenterValue - SELL_Area * Point; // Logic to determine Sell Area 
    double B2 = CenterValue + BUY_Target_1 * Point; // Logic to determine High Break Area 
    double S2 = CenterValue - SELL_Target_1 * Point; // Logic to determine Low Break Area 
    double B3 = CenterValue + BUY_Target_2 * Point; // Logic to determine High Target Area 
    double S3 = CenterValue - SELL_Target_2 * Point; // Logic to determine Low Target Area     
    
    //Redraw Object
    ObjectsRedraw();
    
    // Dolly Colored Levels
    CreateAreaGraphics("BuyArea3", B3, B3, C'0,0,210' );
    CreateAreaGraphics("BuyArea2", B2, B2,BUY_Color_2); 
    CreateAreaGraphics("BuyArea1", B1, B1,BUY_Color_1); 
    CreateCenterLine("DailyOpen",CenterValue,CenterValue,2,0, Silver);
    CreateAreaGraphics("SellArea1", S1, S1,SELL_Color_1 ); 
    CreateAreaGraphics("SellArea2", S2, S2,SELL_Color_2 ); 
    CreateAreaGraphics("SellArea3", S3, S3, C'230,0,0');
      

    //Draw Label
    CreateAreaLabel("LabelBuyArea3","2ND TARGET",B3,C'0,0,210');
    CreateAreaLabel("LabelBuyArea2","1ST TARGET",B2,BUY_Color_2);
    CreateAreaLabel("LabelBuyArea1","BUY AREA",B1,BUY_Color_1);
    CreateAreaLabel("LabelCentreArea","OPEN @ "+DoubleToStr(CenterValue,Digits),CenterValue,Silver);
    CreateAreaLabel("LabelSellArea1","SELL AREA",S1,SELL_Color_1);
    CreateAreaLabel("LabelSellArea2","1ST TARGET",S2,SELL_Color_2);
    CreateAreaLabel("LabelSellArea3","2ND TARGET",S3,C'230,0,0');
        
    //Show Pivot Support & Resistance Lines
    if (Show_Pivot_Lines == true)
    {      
       //Create Pivot Line          
       CreatePivotsLines("RR3",r3,r3,1,0, Gray);
       CreatePivotsLines("RR2",r2,r2,1,0, Gray);
       CreatePivotsLines("RR1",r1,r1,1,0, Gray);
       CreateCenterLine("P1",P,P,2,0, DimGray);
       CreatePivotsLines("SS1",s1,s1,1,0, Gray);
       CreatePivotsLines("SS2",s2,s2,1,0, Gray);
       CreatePivotsLines("SS3",s3,s3,1,0, Gray);
       
       //Draw Pivot Label
       CreatePivotAreaLabel("LabelR3","R3",r3,Gray);
       CreatePivotAreaLabel("LabelR2","R2",r2,Gray);
       CreatePivotAreaLabel("LabelR1","R1",r1,Gray);
       CreatePivotAreaLabel("LabelPV","PIVOT "+ DoubleToStr(P,Digits),P,DimGray);
       CreatePivotAreaLabel("LabelS1","S1",s1,Gray);
       CreatePivotAreaLabel("LabelS2","S2",s2,Gray);
       CreatePivotAreaLabel("LabelS3","S3",s3,Gray);              
    }

   Comment ("\n Dolly Simple 1.0.1 ( BREAKOUT STRATEGY ) "
   +"\n -------------------------------------------------------------------"
   +"\n :::::::::::: DURING AROUND 2 BREAK :::::::::::"
   +"\n -------------------------------------------------------------------"
   +"\n BUY AREA (break) :"
   +"\n # BUY STOP1  "+Symbol()+" TO "+(DoubleToStr (B1,Digits))
   +"\n Set TP "+(DoubleToStr (B2,Digits))+" and SL TO "+(DoubleToStr(S1,Digits))
   +"\n # BUY STOP2  "+Symbol()+" TO "+(DoubleToStr(B2,Digits))
   +"\n Set TP "+(DoubleToStr (B3,Digits))+" and SL TO "+(DoubleToStr (B1,Digits))
   +"\n \n SELL AREA (break) :"
   +"\n # SELL STOP  "+Symbol()+" TO "+(DoubleToStr (S1,Digits))
   +"\n Set TP "+(DoubleToStr (S2,Digits))+" and SL to "+(DoubleToStr (B1,Digits))
   +"\n # SELL STOP2  "+Symbol()+" TO "+(DoubleToStr (S2,Digits))
   +"\n Set TP "+(DoubleToStr (S3,Digits))+" and SL TO "+(DoubleToStr(S1,Digits))
   +"\n -------------------------------------------------------------------"
   +"\n ::::: POSSIBLE REVERSAL TRADES :::::"
   +"\n -------------------------------------------------------------------"
   +"\n LOWER CORRECTION :"
   +"\n # BUY STOP  "+Symbol()+" TO "+(DoubleToStr(S2,Digits))
   +"\n Set TP "+(DoubleToStr(B1,Digits))+" and SL TO "+(DoubleToStr(S3,Digits))
   +"\n \n UPPER CORRECTION :"
   +"\n # SELL STOP  "+Symbol()+" TO "+(DoubleToStr(B2,Digits))
   +"\n Set TP "+(DoubleToStr(S1,Digits))+" and SL TO "+(DoubleToStr(B3,Digits))
   +"\n -------------------------------------------------------------------"
   +"\n \n -------------------------------------------------------------------"
   +"\n :::::: SUPPORT & RESISTANCE TODAY :::::"
   +"\n -------------------------------------------------------------------"
   +"\n Resistance 3 :"+(DoubleToStr(r3,Digits))
   +"\n Resistance 2 :"+(DoubleToStr(r2,Digits))
   +"\n Resistance 1 :"+(DoubleToStr(r1,Digits))
   +"\n -------------------------------------------------------------------"
   +"\n Pivot level :"+(DoubleToStr(P,Digits))
   +"\n -------------------------------------------------------------------"
   +"\n Support 1 :"+(DoubleToStr(s1,Digits))
   +"\n Support 2 :"+(DoubleToStr(s2,Digits))
   +"\n Support 3 :"+(DoubleToStr(s3,Digits))
   +"\n -------------------------------------------------------------------");    

}